==> cscec5bhn-wzxt-api-3.0.1-20220926.030859-94-sources.jar: com/ejianc/business/wzxt/vo/CheckDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 验收明细表
 *
 * @author generator
 *
 */
public class CheckDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long checkId; // 验收主键ID
    private java.lang.Long deliveryId; // 发货主键ID
    private java.lang.Long deliveryDetailId; // 发货明细主键ID
    private java.lang.Long orderId; // 订单主键ID
    private java.lang.Long orderDetailId; // 订单明细主键ID
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别
    private java.lang.String materialTypeName; // 物资类别名称
    private java.lang.String materialCode; // 物料编码
    private java.lang.String unit; // 单位
    private java.lang.String spec; // 规格型号
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    private java.math.BigDecimal checkNumsSum; // 验收数量
    private java.lang.String materialManufacturer; // 生产厂家
    private java.lang.String memo; // 备注
    private java.lang.String instoreId; // 入库单主键
    private java.lang.String instoreDetailId; // 入库单明细主键
    private java.math.BigDecimal instoreNum; // 入库数量
    private java.lang.String materialSourceId; // 物资来源ID
    private java.math.BigDecimal mny; // 无税金额
    private java.math.BigDecimal taxmny; // 含税金额
    private java.math.BigDecimal nprice; // 无税价格
    private java.math.BigDecimal ntaxprice; // 含税价格
    private java.math.BigDecimal taxrate; // 税率
    private java.math.BigDecimal tax; // 税金
    private java.math.BigDecimal weighresult; // 称重结果
    private java.math.BigDecimal unitRatio; // 单位转换系数
    private java.math.BigDecimal weighNum; // 称重数量
    private java.lang.String def1; // 自定义字段1
    private java.lang.String def2; // 自定义字段2
    private java.lang.String def3; // 自定义字段3
    private java.lang.String def4; // 自定义字段4
    private java.lang.String def5; // 自定义字段5
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date rentDate; // 自定义字段5

    /******  mro add begin     ******/
    private BigDecimal mroMny; // mro无税金额
    private BigDecimal mroTaxmny; // mro含税金额
    private BigDecimal mroNprice; // mro无税价格
    private BigDecimal mroNtaxprice; // mro含税价格
    private BigDecimal mroTaxrate; // mro税率
    private BigDecimal mroTax; // mro税金
    private BigDecimal mroDeliverNumsSum; // mro发货数量
    private String mroSupplierSkuCode; // 供应商skuCode 字符类型
    private String mroSupplierSkuId; // 供应商skuId长整型
    private BigDecimal mroUnitRatio; // mro换算率
    private String mroUnit; // mro单位
    private BigDecimal mroCheckNum; // 验收数量
    private String pkAmountlist; // 分录主键

    private String htywnr; // 分录名称

    private Integer surplusFlag; // 库存材料 0 是 1 否
    private String fileIds; //图片主键集合

    public BigDecimal getMroMny() {
        return mroMny;
    }

    public void setMroMny(BigDecimal mroMny) {
        this.mroMny = mroMny;
    }

    public BigDecimal getMroTaxmny() {
        return mroTaxmny;
    }

    public void setMroTaxmny(BigDecimal mroTaxmny) {
        this.mroTaxmny = mroTaxmny;
    }

    public BigDecimal getMroNprice() {
        return mroNprice;
    }

    public void setMroNprice(BigDecimal mroNprice) {
        this.mroNprice = mroNprice;
    }

    public BigDecimal getMroNtaxprice() {
        return mroNtaxprice;
    }

    public void setMroNtaxprice(BigDecimal mroNtaxprice) {
        this.mroNtaxprice = mroNtaxprice;
    }

    public BigDecimal getMroTaxrate() {
        return mroTaxrate;
    }

    public void setMroTaxrate(BigDecimal mroTaxrate) {
        this.mroTaxrate = mroTaxrate;
    }

    public BigDecimal getMroTax() {
        return mroTax;
    }

    public void setMroTax(BigDecimal mroTax) {
        this.mroTax = mroTax;
    }

    public BigDecimal getMroDeliverNumsSum() {
        return mroDeliverNumsSum;
    }

    public void setMroDeliverNumsSum(BigDecimal mroDeliverNumsSum) {
        this.mroDeliverNumsSum = mroDeliverNumsSum;
    }

    public String getMroSupplierSkuCode() {
        return mroSupplierSkuCode;
    }

    public void setMroSupplierSkuCode(String mroSupplierSkuCode) {
        this.mroSupplierSkuCode = mroSupplierSkuCode;
    }

    public String getMroSupplierSkuId() {
        return mroSupplierSkuId;
    }

    public void setMroSupplierSkuId(String mroSupplierSkuId) {
        this.mroSupplierSkuId = mroSupplierSkuId;
    }

    public BigDecimal getMroUnitRatio() {
        return mroUnitRatio;
    }

    public void setMroUnitRatio(BigDecimal mroUnitRatio) {
        this.mroUnitRatio = mroUnitRatio;
    }

    public String getMroUnit() {
        return mroUnit;
    }

    public void setMroUnit(String mroUnit) {
        this.mroUnit = mroUnit;
    }

    public BigDecimal getMroCheckNum() {
        return mroCheckNum;
    }

    public void setMroCheckNum(BigDecimal mroCheckNum) {
        this.mroCheckNum = mroCheckNum;
    }

    /******  mro add end     ******/

    public Date getRentDate() {
        return rentDate;
    }

    public void setRentDate(Date rentDate) {
        this.rentDate = rentDate;
    }



    /**
     * 验收主键ID
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 发货主键ID
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键ID
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 发货明细主键ID
     */
    public java.lang.Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    /**
     * 发货明细主键ID
     */
    public void setDeliveryDetailId(java.lang.Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 订单明细主键ID
     */
    public java.lang.Long getOrderDetailId() {
        return orderDetailId;
    }

    /**
     * 订单明细主键ID
     */
    public void setOrderDetailId(java.lang.Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 入库单主键
     */
    public java.lang.String getInstoreId() {
        return instoreId;
    }

    /**
     * 入库单主键
     */
    public void setInstoreId(java.lang.String instoreId) {
        this.instoreId = instoreId;
    }
    /**
     * 入库单明细主键
     */
    public java.lang.String getInstoreDetailId() {
        return instoreDetailId;
    }

    /**
     * 入库单明细主键
     */
    public void setInstoreDetailId(java.lang.String instoreDetailId) {
        this.instoreDetailId = instoreDetailId;
    }
    /**
     * 入库数量
     */
    public java.math.BigDecimal getInstoreNum() {
        return instoreNum;
    }

    /**
     * 入库数量
     */
    public void setInstoreNum(java.math.BigDecimal instoreNum) {
        this.instoreNum = instoreNum;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源ID
     */
    public void setMaterialSourceId(java.lang.String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 无税金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 无税金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getTaxmny() {
        return taxmny;
    }

    /**
     * 含税金额
     */
    public void setTaxmny(java.math.BigDecimal taxmny) {
        this.taxmny = taxmny;
    }
    /**
     * 无税价格
     */
    public java.math.BigDecimal getNprice() {
        return nprice;
    }

    /**
     * 无税价格
     */
    public void setNprice(java.math.BigDecimal nprice) {
        this.nprice = nprice;
    }
    /**
     * 含税价格
     */
    public java.math.BigDecimal getNtaxprice() {
        return ntaxprice;
    }

    /**
     * 含税价格
     */
    public void setNtaxprice(java.math.BigDecimal ntaxprice) {
        this.ntaxprice = ntaxprice;
    }
    /**
     * 税率
     */
    public java.math.BigDecimal getTaxrate() {
        return taxrate;
    }

    /**
     * 税率
     */
    public void setTaxrate(java.math.BigDecimal taxrate) {
        this.taxrate = taxrate;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 称重结果
     */
    public java.math.BigDecimal getWeighresult() {
        return weighresult;
    }

    /**
     * 称重结果
     */
    public void setWeighresult(java.math.BigDecimal weighresult) {
        this.weighresult = weighresult;
    }
    /**
     * 单位转换系数
     */
    public java.math.BigDecimal getUnitRatio() {
        return unitRatio;
    }

    /**
     * 单位转换系数
     */
    public void setUnitRatio(java.math.BigDecimal unitRatio) {
        this.unitRatio = unitRatio;
    }
    /**
     * 称重数量
     */
    public java.math.BigDecimal getWeighNum() {
        return weighNum;
    }

    /**
     * 称重数量
     */
    public void setWeighNum(java.math.BigDecimal weighNum) {
        this.weighNum = weighNum;
    }
    /**
     * 自定义字段1
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 自定义字段1
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 自定义字段2
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 自定义字段2
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 自定义字段3
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 自定义字段3
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 自定义字段4
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 自定义字段1
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 自定义字段5
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 自定义字段1
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }

    public String getPkAmountlist() {
        return pkAmountlist;
    }

    public void setPkAmountlist(String pkAmountlist) {
        this.pkAmountlist = pkAmountlist;
    }

    public String getHtywnr() {
        return htywnr;
    }

    public void setHtywnr(String htywnr) {
        this.htywnr = htywnr;
    }

    public Integer getSurplusFlag() {
        return surplusFlag;
    }

    public void setSurplusFlag(Integer surplusFlag) {
        this.surplusFlag = surplusFlag;
    }

    public String getFileIds() {
        return fileIds;
    }

    public void setFileIds(String fileIds) {
        this.fileIds = fileIds;
    }
}

==> cscec5bhn-wzxt-api-3.0.1-20221025.030818-100-sources.jar: com/ejianc/business/wzxt/vo/CheckDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 验收明细表
 *
 * @author generator
 *
 */
public class CheckDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long checkId; // 验收主键ID
    private java.lang.Long deliveryId; // 发货主键ID
    private java.lang.Long deliveryDetailId; // 发货明细主键ID
    private java.lang.Long orderId; // 订单主键ID
    private java.lang.Long orderDetailId; // 订单明细主键ID
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别
    private java.lang.String materialTypeName; // 物资类别名称
    private java.lang.String materialCode; // 物料编码
    private java.lang.String unit; // 单位
    private java.lang.String spec; // 规格型号
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    private java.math.BigDecimal checkNumsSum; // 验收数量
    private java.lang.String materialManufacturer; // 生产厂家
    private java.lang.String memo; // 备注
    private java.lang.String instoreId; // 入库单主键
    private java.lang.String instoreDetailId; // 入库单明细主键
    private java.math.BigDecimal instoreNum; // 入库数量
    private java.lang.String materialSourceId; // 物资来源ID
    private java.math.BigDecimal mny; // 无税金额
    private java.math.BigDecimal taxmny; // 含税金额
    private java.math.BigDecimal nprice; // 无税价格
    private java.math.BigDecimal ntaxprice; // 含税价格
    private java.math.BigDecimal taxrate; // 税率
    private java.math.BigDecimal tax; // 税金
    private java.math.BigDecimal weighresult; // 称重结果
    private java.math.BigDecimal unitRatio; // 单位转换系数
    private java.math.BigDecimal weighNum; // 称重数量
    private java.lang.String def1; // 自定义字段1
    private java.lang.String def2; // 自定义字段2
    private java.lang.String def3; // 自定义字段3
    private java.lang.String def4; // 自定义字段4
    private java.lang.String def5; // 自定义字段5
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date rentDate; // 自定义字段5

    /******  mro add begin     ******/
    private BigDecimal mroMny; // mro无税金额
    private BigDecimal mroTaxmny; // mro含税金额
    private BigDecimal mroNprice; // mro无税价格
    private BigDecimal mroNtaxprice; // mro含税价格
    private BigDecimal mroTaxrate; // mro税率
    private BigDecimal mroTax; // mro税金
    private BigDecimal mroDeliverNumsSum; // mro发货数量
    private String mroSupplierSkuCode; // 供应商skuCode 字符类型
    private String mroSupplierSkuId; // 供应商skuId长整型
    private BigDecimal mroUnitRatio; // mro换算率
    private String mroUnit; // mro单位
    private BigDecimal mroCheckNum; // 验收数量
    private String pkAmountlist; // 分录主键

    private String htywnr; // 分录名称

    private Integer surplusFlag; // 库存材料 0 是 1 否
    private String fileIds; //图片主键集合

    public BigDecimal getMroMny() {
        return mroMny;
    }

    public void setMroMny(BigDecimal mroMny) {
        this.mroMny = mroMny;
    }

    public BigDecimal getMroTaxmny() {
        return mroTaxmny;
    }

    public void setMroTaxmny(BigDecimal mroTaxmny) {
        this.mroTaxmny = mroTaxmny;
    }

    public BigDecimal getMroNprice() {
        return mroNprice;
    }

    public void setMroNprice(BigDecimal mroNprice) {
        this.mroNprice = mroNprice;
    }

    public BigDecimal getMroNtaxprice() {
        return mroNtaxprice;
    }

    public void setMroNtaxprice(BigDecimal mroNtaxprice) {
        this.mroNtaxprice = mroNtaxprice;
    }

    public BigDecimal getMroTaxrate() {
        return mroTaxrate;
    }

    public void setMroTaxrate(BigDecimal mroTaxrate) {
        this.mroTaxrate = mroTaxrate;
    }

    public BigDecimal getMroTax() {
        return mroTax;
    }

    public void setMroTax(BigDecimal mroTax) {
        this.mroTax = mroTax;
    }

    public BigDecimal getMroDeliverNumsSum() {
        return mroDeliverNumsSum;
    }

    public void setMroDeliverNumsSum(BigDecimal mroDeliverNumsSum) {
        this.mroDeliverNumsSum = mroDeliverNumsSum;
    }

    public String getMroSupplierSkuCode() {
        return mroSupplierSkuCode;
    }

    public void setMroSupplierSkuCode(String mroSupplierSkuCode) {
        this.mroSupplierSkuCode = mroSupplierSkuCode;
    }

    public String getMroSupplierSkuId() {
        return mroSupplierSkuId;
    }

    public void setMroSupplierSkuId(String mroSupplierSkuId) {
        this.mroSupplierSkuId = mroSupplierSkuId;
    }

    public BigDecimal getMroUnitRatio() {
        return mroUnitRatio;
    }

    public void setMroUnitRatio(BigDecimal mroUnitRatio) {
        this.mroUnitRatio = mroUnitRatio;
    }

    public String getMroUnit() {
        return mroUnit;
    }

    public void setMroUnit(String mroUnit) {
        this.mroUnit = mroUnit;
    }

    public BigDecimal getMroCheckNum() {
        return mroCheckNum;
    }

    public void setMroCheckNum(BigDecimal mroCheckNum) {
        this.mroCheckNum = mroCheckNum;
    }

    /******  mro add end     ******/

    public Date getRentDate() {
        return rentDate;
    }

    public void setRentDate(Date rentDate) {
        this.rentDate = rentDate;
    }


    /******  rent add begin     ******/

    private Integer signRowType; //合同签订方式1-分类 2-材料
    private String unitId; // 档案单位主键
    private String unitName; // 档案单位名称
    private String realUnitId; // 实物单位主键
    private String realUnitName; // 实物单位名称
    private BigDecimal realTransScale; // 实物转换系数
    private BigDecimal realNum; // 实物验收数量
    private String rentUnitId; // 计租单位主键
    private String rentUnitName; // 计租单位名称
    private BigDecimal rentTransScale; // 计租转换系数
    private BigDecimal rentNum; // 计租验收数量
    private String ncDetailId; // NC清单主键

    // 验收明细子表
    private List<CheckAllotVO> allotList = new ArrayList<>();


    public Integer getSignRowType() {
        return signRowType;
    }

    public void setSignRowType(Integer signRowType) {
        this.signRowType = signRowType;
    }

    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }

    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }

    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }

    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }

    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }

    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }

    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }

    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }

    public String getNcDetailId() {
        return ncDetailId;
    }

    public void setNcDetailId(String ncDetailId) {
        this.ncDetailId = ncDetailId;
    }

    public List<CheckAllotVO> getAllotList() {
        return allotList;
    }

    public void setAllotList(List<CheckAllotVO> allotList) {
        this.allotList = allotList;
    }

    /******  rent add end     ******/


    /**
     * 验收主键ID
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 发货主键ID
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键ID
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 发货明细主键ID
     */
    public java.lang.Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    /**
     * 发货明细主键ID
     */
    public void setDeliveryDetailId(java.lang.Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 订单明细主键ID
     */
    public java.lang.Long getOrderDetailId() {
        return orderDetailId;
    }

    /**
     * 订单明细主键ID
     */
    public void setOrderDetailId(java.lang.Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 入库单主键
     */
    public java.lang.String getInstoreId() {
        return instoreId;
    }

    /**
     * 入库单主键
     */
    public void setInstoreId(java.lang.String instoreId) {
        this.instoreId = instoreId;
    }
    /**
     * 入库单明细主键
     */
    public java.lang.String getInstoreDetailId() {
        return instoreDetailId;
    }

    /**
     * 入库单明细主键
     */
    public void setInstoreDetailId(java.lang.String instoreDetailId) {
        this.instoreDetailId = instoreDetailId;
    }
    /**
     * 入库数量
     */
    public java.math.BigDecimal getInstoreNum() {
        return instoreNum;
    }

    /**
     * 入库数量
     */
    public void setInstoreNum(java.math.BigDecimal instoreNum) {
        this.instoreNum = instoreNum;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源ID
     */
    public void setMaterialSourceId(java.lang.String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 无税金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 无税金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getTaxmny() {
        return taxmny;
    }

    /**
     * 含税金额
     */
    public void setTaxmny(java.math.BigDecimal taxmny) {
        this.taxmny = taxmny;
    }
    /**
     * 无税价格
     */
    public java.math.BigDecimal getNprice() {
        return nprice;
    }

    /**
     * 无税价格
     */
    public void setNprice(java.math.BigDecimal nprice) {
        this.nprice = nprice;
    }
    /**
     * 含税价格
     */
    public java.math.BigDecimal getNtaxprice() {
        return ntaxprice;
    }

    /**
     * 含税价格
     */
    public void setNtaxprice(java.math.BigDecimal ntaxprice) {
        this.ntaxprice = ntaxprice;
    }
    /**
     * 税率
     */
    public java.math.BigDecimal getTaxrate() {
        return taxrate;
    }

    /**
     * 税率
     */
    public void setTaxrate(java.math.BigDecimal taxrate) {
        this.taxrate = taxrate;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 称重结果
     */
    public java.math.BigDecimal getWeighresult() {
        return weighresult;
    }

    /**
     * 称重结果
     */
    public void setWeighresult(java.math.BigDecimal weighresult) {
        this.weighresult = weighresult;
    }
    /**
     * 单位转换系数
     */
    public java.math.BigDecimal getUnitRatio() {
        return unitRatio;
    }

    /**
     * 单位转换系数
     */
    public void setUnitRatio(java.math.BigDecimal unitRatio) {
        this.unitRatio = unitRatio;
    }
    /**
     * 称重数量
     */
    public java.math.BigDecimal getWeighNum() {
        return weighNum;
    }

    /**
     * 称重数量
     */
    public void setWeighNum(java.math.BigDecimal weighNum) {
        this.weighNum = weighNum;
    }
    /**
     * 自定义字段1
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 自定义字段1
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 自定义字段2
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 自定义字段2
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 自定义字段3
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 自定义字段3
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 自定义字段4
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 自定义字段1
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 自定义字段5
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 自定义字段1
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }

    public String getPkAmountlist() {
        return pkAmountlist;
    }

    public void setPkAmountlist(String pkAmountlist) {
        this.pkAmountlist = pkAmountlist;
    }

    public String getHtywnr() {
        return htywnr;
    }

    public void setHtywnr(String htywnr) {
        this.htywnr = htywnr;
    }

    public Integer getSurplusFlag() {
        return surplusFlag;
    }

    public void setSurplusFlag(Integer surplusFlag) {
        this.surplusFlag = surplusFlag;
    }

    public String getFileIds() {
        return fileIds;
    }

    public void setFileIds(String fileIds) {
        this.fileIds = fileIds;
    }
}
